@@ -11,16 +11,18 @@ from .util import commit_from
 
 class PPSMixin:
     def inspect_job(self, job_id, block_state=None, output_commit=None, full=None):
-        """
-        Inspects a job with a given ID. Returns a `JobInfo`.
+        """Inspects a job with a given ID. Returns a ``JobInfo``.
 
-        Params:
-
-        * `job_id`: The ID of the job to inspect.
-        * `block_state`: If true, block until the job completes.
-        * `output_commit`: An optional tuple, string, or `Commit` object
-        representing an output commit to filter on.
-        * `full`: If true, include worker status.
+        Parameters
+        ----------
+        job_id : str
+            The ID of the job to inspect.
+        block_state : bool, optional
+            If true, block until the job completes.
+        output_commit : Union[tuple, str, Commit protobuf], optional
+            Represents an output commit to filter on.
+        full : bool, optional
+            If true, include worker status.
         """
         return self._req(
             Service.PPS,
@@ -42,32 +44,36 @@ class PPSMixin:
         full=None,
         jqFilter=None,
     ):
-        """
-        Lists jobs. Yields `JobInfo` objects.
+        """.. # noqa: W505
 
-        Params:
+        Lists jobs. Yields ``JobInfo`` objects.
 
-        * `pipeline_name`: An optional string representing a pipeline name to
-          filter on.
-        * `input_commit`: An optional list of tuples, strings, or `Commit`
-          objects representing input commits to filter on.
-        * `output_commit`: An optional tuple, string, or `Commit` object
-          representing an output commit to filter on.
-        * `history`: An optional int that indicates to return jobs from
-          historical versions of pipelines. Semantics are:
-            * 0: Return jobs from the current version of the pipeline or
-              pipelines.
-            * 1: Return the above and jobs from the next most recent version
-            * 2: etc.
-            * -1: Return jobs from all historical versions.
-        * `full`: An optional bool indicating whether the result should
-          include all pipeline details in each `JobInfo`, or limited information
-          including name and status, but excluding information in the pipeline
-          spec. Leaving this `None` (or `False`) can make the call significantly
-          faster in clusters with a large number of pipelines and jobs. Note
-          that if `input_commit` is set, this field is coerced to `True`.
-        * `jqFilter`: An optional string containing a `jq` filter that can
-          restrict the list of jobs returned, for convenience
+        Parameters
+        ----------
+        pipeline_name : str, optional
+            A pipeline name to filter on.
+        input_commit : List[Union[tuple, str, Commit protobuf]], optional
+            An optional list representing input commits to filter on.
+        output_commit : Union[tuple, str, Commit protobuf], optional
+            Represents an output commit to filter on.
+        history : int, optional
+            Indicates to return jobs from historical versions of pipelines.
+            Semantics are:
+
+            - 0: Return jobs from the current version of the pipeline or pipelines.
+            - 1: Return the above and jobs from the next most recent version
+            - 2: etc.
+            - -1: Return jobs from all historical versions.
+
+        full : bool, optional
+            Whether the result should include all pipeline details in each
+            ``JobInfo``, or limited information including name and status, but
+            excluding information in the pipeline spec. Leaving this ``None``
+            (or ``False``) can make the call significantly faster in clusters
+            with a large number of pipelines and jobs. Note that if
+            `input_commit` is set, this field is coerced to ``True``.
+        jqFilter : str, optional
+            A ``jq`` filter that can restrict the list of jobs returned.
         """
         if isinstance(input_commit, list):
             input_commit = [commit_from(ic) for ic in input_commit]
@@ -90,16 +96,16 @@ class PPSMixin:
         )
 
     def flush_job(self, commits, pipeline_names=None):
-        """
-        Blocks until all of the jobs which have a set of commits as
-        provenance have finished. Yields `JobInfo` objects.
+        """Blocks until all of the jobs which have a set of commits as
+        provenance have finished. Yields ``JobInfo`` objects.
 
-        Params:
-
-        * `commits`: A list of tuples, strings, or `Commit` objects
-        representing the commits to flush.
-        * `pipeline_names`: An optional list of strings specifying pipeline
-        names. If specified, only jobs within these pipelines will be flushed.
+        Parameters
+        ----------
+        commits : List[Union[tuple, str, Commit protobuf]]
+            A list representing the commits to flush.
+        pipeline_names : List[str], optional
+            A list of strings specifying pipeline names. If specified, only
+            jobs within these pipelines will be flushed.
         """
         if pipeline_names is not None:
             to_pipelines = [pps_proto.Pipeline(name=name) for name in pipeline_names]
@@ -114,33 +120,34 @@ class PPSMixin:
         )
 
     def delete_job(self, job_id):
-        """
-        Deletes a job by its ID.
+        """Deletes a job by its ID.
 
-        Params:
-
-        * `job_id`: The ID of the job to delete.
+        Parameters
+        ----------
+        job_id : str
+            The ID of the job to delete.
         """
         return self._req(Service.PPS, "DeleteJob", job=pps_proto.Job(id=job_id))
 
     def stop_job(self, job_id):
-        """
-        Stops a job by its ID.
+        """Stops a job by its ID.
 
-        Params:
-
-        * `job_id`: The ID of the job to stop.
+        Parameters
+        ----------
+        job_id : str
+            The ID of the job to stop.
         """
         return self._req(Service.PPS, "StopJob", job=pps_proto.Job(id=job_id))
 
     def inspect_datum(self, job_id, datum_id):
-        """
-        Inspects a datum. Returns a `DatumInfo` object.
+        """Inspects a datum. Returns a ``DatumInfo`` object.
 
-        Params:
-
-        * `job_id`: The ID of the job.
-        * `datum_id`: The ID of the datum.
+        Parameters
+        ----------
+        job_id : str
+            The ID of the job.
+        datum_id : str
+            The ID of the datum.
         """
         return self._req(
             Service.PPS,
@@ -151,19 +158,22 @@ class PPSMixin:
     def list_datum(
         self, job_id=None, page_size=None, page=None, input=None, status_only=None
     ):
-        """
-        Lists datums. Yields `ListDatumStreamResponse` objects.
+        """Lists datums. Yields ``ListDatumStreamResponse`` objects.
 
-        Params:
-
-        * `job_id`: An optional int specifying the ID of a job. Exactly one of
-          `job_id` (real) or `input` (hypothetical) must be set.
-        * `page_size`: An optional int specifying the size of the page.
-        * `page`: An optional int specifying the page number.
-        * `input`: An optional `Input` object. If set in lieu of `job_id`,
-          list_datum returns the datums that would be given to a hypothetical
-          job that used `input` as its input spec. Exactly one of `job_id`
-          (real) or `input` (hypothetical) must be set.
+        Parameters
+        ----------
+        job_id : str, optional
+            The ID of a job. Exactly one of `job_id` (real) or `input`
+            (hypothetical) must be set.
+        page_size : int, optional
+            The size of the page.
+        page : int, optional
+            The page number.
+        input : Input protobuf, optional
+            If set in lieu of `job_id`, ``list_datum()`` returns the datums
+            that would be given to a hypothetical job that used `input` as its
+            input spec. Exactly one of `job_id` (real) or `input`
+            (hypothetical) must be set.
         """
         return self._req(
             Service.PPS,
@@ -176,13 +186,14 @@ class PPSMixin:
         )
 
     def restart_datum(self, job_id, data_filters=None):
-        """
-        Restarts a datum.
+        """Restarts a datum.
 
-        Params:
-
-        * `job_id`: The ID of the job.
-        * `data_filters`: An optional iterable of strings.
+        Parameters
+        ----------
+        job_id : str
+            The ID of the job.
+        data_filters : List[str], optional
+            An optional iterable of strings.
         """
         return self._req(
             Service.PPS,
@@ -230,44 +241,69 @@ class PPSMixin:
         document:
         http://docs.pachyderm.io/en/latest/reference/pipeline_spec.html
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
-        * `transform`: A `Transform` object.
-        * `parallelism_spec`: An optional `ParallelismSpec` object.
-        * `hashtree_spec`: An optional `HashtreeSpec` object.
-        * `egress`: An optional `Egress` object.
-        * `update`: An optional bool specifying whether this should behave as
-        an upsert.
-        * `output_branch`: An optional string representing the branch to output
-        results on.
-        * `resource_requests`: An optional `ResourceSpec` object.
-        * `resource_limits`: An optional `ResourceSpec` object.
-        * `input`: An optional `Input` object.
-        * `description`: An optional string describing the pipeline.
-        * `cache_size`: An optional string.
-        * `enable_stats`: An optional bool.
-        * `reprocess`: An optional bool. If true, pachyderm forces the pipeline
-        to reprocess all datums. It only has meaning if `update` is `True`.
-        * `max_queue_size`: An optional int.
-        * `service`: An optional `Service` object.
-        * `chunk_spec`: An optional `ChunkSpec` object.
-        * `datum_timeout`: An optional `Duration` object.
-        * `job_timeout`: An optional `Duration` object.
-        * `salt`: An optional string.
-        * `standby`: An optional bool.
-        * `datum_tries`: An optional int.
-        * `scheduling_spec`: An optional `SchedulingSpec` object.
-        * `pod_patch`: An optional string.
-        * `spout`: An optional `Spout` object.
-        * `spec_commit`: An optional `Commit` object.
-        * `metadata`: An optional `Metadata` object.
-        * `s3_out`: An optional bool specifying whether the output repo should
-        be exposed as an s3 gateway bucket.
-        * `sidecar_resource_limits`: An optional `ResourceSpec` setting
-        resource limits for the pipeline sidecar.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
+        transform : Transform protobuf
+            A ``Transform`` object.
+        parallelism_spec : ParallelismSpec protobuf, optional
+            An optional ``ParallelismSpec`` object.
+        hashtree_spec : HashtreeSpec protobuf, optional
+            An optional ``HashtreeSpec`` object.
+        egress : Egress protobuf, optional
+            An optional ``Egress`` object.
+        update : bool, optional
+            Whether this should behave as an upsert.
+        output_branch : str, optional
+            The branch to output results on.
+        resource_requests : ResourceSpec protobuf, optional
+            An optional ``ResourceSpec`` object.
+        resource_limits : ResourceSpec protobuf, optional
+            An optional ``ResourceSpec`` object.
+        input : Input protobuf, optional
+            An optional ``Input`` object.
+        description : str, optional
+            Description of the pipeline.
+        cache_size : str, optional
+            An optional string.
+        enable_stats : bool, optional
+            An optional bool.
+        reprocess : bool, optional
+            If true, Pachyderm forces the pipeline to reprocess all datums. It
+            only has meaning if `update` is ``True``.
+        max_queue_size : int, optional
+            An optional int.
+        service : Service protobuf, optional
+            An optional ``Service`` object.
+        chunk_spec : ChunkSpec protobuf, optional
+            An optional ``ChunkSpec`` object.
+        datum_timeout : Duration protobuf, optional
+            An optional ``Duration`` object.
+        job_timeout : Duration protobuf, optional
+            An optional ``Duration`` object.
+        salt : str, optional
+            An optional string.
+        standby : bool, optional
+            An optional bool.
+        datum_tries : int, optional
+            An optional int.
+        scheduling_spec : SchedulingSpec protobuf, optional
+            An optional ``SchedulingSpec`` object.
+        pod_patch : str, optional
+            An optional string.
+        spout : Spout protobuf, optional
+            An optional ``Spout`` object.
+        spec_commit : Commit protobuf, optional
+            An optional ``Commit`` object.
+        metadata : Metadata protobuf, optional
+            An optional ``Metadata`` object.
+        s3_out : bool, optional
+            Unused.
+        sidecar_resource_limits : ResourceSpec protobuf, optional
+            An optional ``ResourceSpec`` setting resource limits for the
+            pipeline sidecar.
         """
-
         # Support for build step-enabled pipelines. This is a python port of
         # the equivalent functionality in pachyderm core's
         # 'src/server/pps/cmds/cmds.go', and any changes made here likely have
@@ -398,16 +434,17 @@ class PPSMixin:
         )
 
     def create_pipeline_from_request(self, req):
-        """
-        Creates a pipeline from a `CreatePipelineRequest` object. Usually this
-        would be used in conjunction with `util.parse_json_pipeline_spec` or
-        `util.parse_dict_pipeline_spec`. If you're in pure python and not
+        """Creates a pipeline from a ``CreatePipelineRequest`` object. Usually
+        this would be used in conjunction with
+        ``util.parse_json_pipeline_spec()`` or
+        ``util.parse_dict_pipeline_spec()``. If you're in pure python and not
         working with a pipeline spec file, the sibling method
-        `create_pipeline` is more ergonomic.
+        ``create_pipeline()`` is more ergonomic.
 
-        Params:
-
-        * `req`: A `CreatePipelineRequest` object.
+        Parameters
+        ----------
+        req : CreatePipelineRequest protobuf
+            A `CreatePipelineRequest` object.
         """
         return self._req(Service.PPS, "CreatePipeline", req=req)
 
@@ -441,45 +478,68 @@ class PPSMixin:
         spout=None,
         spec_commit=None,
     ):
-        """
-        Creates a pipeline. For more info, please refer to the pipeline spec
+        """Creates a pipeline. For more info, please refer to the pipeline spec
         document:
         http://docs.pachyderm.io/en/latest/reference/pipeline_spec.html
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
-        * `tf_job`: A `TFJob` object. Pachyderm uses this to create TFJobs
-        when running in a Kubernetes cluster on which kubeflow has been
-        installed.
-        * `parallelism_spec`: An optional `ParallelismSpec` object.
-        * `hashtree_spec`: An optional `HashtreeSpec` object.
-        * `egress`: An optional `Egress` object.
-        * `update`: An optional bool specifying whether this should behave as
-        an upsert.
-        * `output_branch`: An optional string representing the branch to output
-        results on.
-        * `scale_down_threshold`: An optional `Duration` object.
-        * `resource_requests`: An optional `ResourceSpec` object.
-        * `resource_limits`: An optional `ResourceSpec` object.
-        * `input`: An optional `Input` object.
-        * `description`: An optional string describing the pipeline.
-        * `cache_size`: An optional string.
-        * `enable_stats`: An optional bool.
-        * `reprocess`: An optional bool. If true, pachyderm forces the pipeline
-        to reprocess all datums. It only has meaning if `update` is `True`.
-        * `max_queue_size`: An optional int.
-        * `service`: An optional `Service` object.
-        * `chunk_spec`: An optional `ChunkSpec` object.
-        * `datum_timeout`: An optional `Duration` object.
-        * `job_timeout`: An optional `Duration` object.
-        * `salt`: An optional string.
-        * `standby`: An optional bool.
-        * `datum_tries`: An optional int.
-        * `scheduling_spec`: An optional `SchedulingSpec` object.
-        * `pod_patch`: An optional string.
-        * `spout`: An optional `Spout` object.
-        * `spec_commit`: An optional `Commit` object.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
+        tf_job : TFJob protobuf
+            Pachyderm uses this to create TFJobs when running in a Kubernetes
+            cluster on which kubeflow has been installed.
+        parallelism_spec : ParallelismSpec protobuf, optional
+            An optional ``ParallelismSpec`` object.
+        hashtree_spec : HashtreeSpec protobuf, optional
+            An optional ``HashtreeSpec`` object.
+        egress : Egress protobuf, optional
+            An optional ``Egress`` object.
+        update : bool, optional
+            Whether this should behave as an upsert.
+        output_branch : str, optional
+            The branch to output results on.
+        scale_down_threshold : Duration protobuf, optional
+            An optional `Duration` object.
+        resource_requests : ResourceSpec protobuf, optional
+            An optional ``ResourceSpec`` object.
+        resource_limits : ResourceSpec protobuf, optional
+            An optional ``ResourceSpec`` object.
+        input : Input protobuf, optional
+            An optional ``Input`` object.
+        description : str, optional
+            Description of the pipeline.
+        cache_size : str, optional
+            An optional string.
+        enable_stats : bool, optional
+            An optional bool.
+        reprocess : bool, optional
+            If true, Pachyderm forces the pipeline to reprocess all datums. It
+            only has meaning if `update` is ``True``.
+        max_queue_size : int, optional
+            An optional int.
+        service : Service protobuf, optional
+            An optional ``Service`` object.
+        chunk_spec : ChunkSpec protobuf, optional
+            An optional ``ChunkSpec`` object.
+        datum_timeout : Duration protobuf, optional
+            An optional ``Duration`` object.
+        job_timeout : Duration protobuf, optional
+            An optional ``Duration`` object.
+        salt : str, optional
+            An optional string.
+        standby : bool, optional
+            An optional bool.
+        datum_tries : int, optional
+            An optional int.
+        scheduling_spec : SchedulingSpec protobuf, optional
+            An optional ``SchedulingSpec`` object.
+        pod_patch : str, optional
+            An optional string.
+        spout : Spout protobuf, optional
+            An optional ``Spout`` object.
+        spec_commit : Commit protobuf, optional
+            An optional ``Commit`` object.
         """
         return self._req(
             Service.PPS,
@@ -514,19 +574,22 @@ class PPSMixin:
         )
 
     def inspect_pipeline(self, pipeline_name, history=None):
-        """
-        Inspects a pipeline. Returns a `PipelineInfo` object.
+        """.. # noqa: W505
 
-        Params:
+        Inspects a pipeline. Returns a ``PipelineInfo`` object.
 
-        * `pipeline_name`: A string representing the pipeline name.
-        * `history`: An optional int that indicates to return historical
-        versions of pipelines. Semantics are:
-            * 0: Return current version of pipelines.
-            * 1: Return the above and pipelines from the next most recent
-            version.
-            * 2: etc.
-            * -1: Return pipelines from all historical versions.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
+        history : int, optional
+            Indicates to return historical versions of pipelines. Semantics
+            are:
+
+            - 0: Return current version of pipelines.
+            - 1: Return the above and pipelines from the next most recent version.
+            - 2: etc.
+            - -1: Return pipelines from all historical versions.
         """
         pipeline = pps_proto.Pipeline(name=pipeline_name)
 
@@ -542,25 +605,28 @@ class PPSMixin:
             return pipelines[0] if len(pipelines) else None
 
     def list_pipeline(self, history=None, allow_incomplete=None, jqFilter=None):
-        """
+        """.. # noqa: W505
+
         Lists pipelines. Returns a `PipelineInfos` object.
 
-        Params:
+        Parameters
+        ----------
+        history : int, optional
+            Indicates to return historical versions of pipelines. Semantics
+            are:
 
-        * `history`: An optional int that indicates to return historical
-        versions of pipelines. Semantics are:
-            * 0: Return current version of pipelines.
-            * 1: Return the above and pipelines from the next most recent
-            version.
-            * 2: etc.
-            * -1: Return pipelines from all historical versions.
-        * `allow_incomplete`: An optional boolean that, if set to `True`, causes
-          `list_pipeline` to return PipelineInfos with incomplete data where the
-          pipeline spec cannot beretrieved. Incomplete PipelineInfos will have a
-          nil Transform field, but will have the fields present in
-          EtcdPipelineInfo.
-        * `jqFilter`: An optional string containing a `jq` filter that can
-          restrict the list of pipelines returned, for convenience.
+            - 0: Return current version of pipelines.
+            - 1: Return the above and pipelines from the next most recent version.
+            - 2: etc.
+            - -1: Return pipelines from all historical versions.
+
+        allow_incomplete : bool, optional
+            If True, causes ``list_pipeline()`` to return ``PipelineInfos``
+            with incomplete data where the pipeline spec cannot be retrieved.
+            Incomplete ``PipelineInfos`` will have a ``None`` `Transform`
+            field, but will have the fields present in ``EtcdPipelineInfo``.
+        jqFilter : str, optional
+            A ``jq`` filter that can restrict the list of pipelines returned.
         """
         return self._req(
             Service.PPS,
@@ -573,18 +639,21 @@ class PPSMixin:
     def delete_pipeline(
         self, pipeline_name, force=None, keep_repo=None, split_transaction=None
     ):
-        """
-        Deletes a pipeline.
+        """Deletes a pipeline.
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
-        * `force`: Whether to force delete.
-        * `keep_repo`: Whether to keep the repo.
-        * `split_transaction`: An optional bool that controls whether Pachyderm
-          attempts to delete the pipeline in a single database transaction.
-          Setting this to `True` can work around certain Pachyderm errors, but,
-          if set, the `delete_repo` call may need to be retried.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
+        force : bool, optional
+            Whether to force delete.
+        keep_repo : bool, optional
+            Whether to keep the output repo.
+        split_transaction : bool, optional
+            Whether Pachyderm attempts to delete the pipeline in a single
+            database transaction. Setting this to ``True`` can work around
+            certain Pachyderm errors, but, if set, the ``delete_repo()` call
+            may need to be retried.
         """
         return self._req(
             Service.PPS,
@@ -596,22 +665,22 @@ class PPSMixin:
         )
 
     def delete_all_pipelines(self, force=None):
-        """
-        Deletes all pipelines.
+        """Deletes all pipelines.
 
-        Params:
-
-        * `force`: Whether to force delete.
+        Parameters
+        ----------
+        force : bool, optional
+            Whether to force delete.
         """
         return self._req(Service.PPS, "DeletePipeline", all=True, force=force)
 
     def start_pipeline(self, pipeline_name):
-        """
-        Starts a pipeline.
+        """Starts a pipeline.
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
         """
         return self._req(
             Service.PPS,
@@ -620,27 +689,28 @@ class PPSMixin:
         )
 
     def stop_pipeline(self, pipeline_name):
-        """
-        Stops a pipeline.
+        """Stops a pipeline.
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
         """
         return self._req(
             Service.PPS, "StopPipeline", pipeline=pps_proto.Pipeline(name=pipeline_name)
         )
 
     def run_pipeline(self, pipeline_name, provenance=None, job_id=None):
-        """
-        Runs a pipeline.
+        """Runs a pipeline.
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
-        * `provenance`: An optional iterable of `CommitProvenance` objects
-        representing the pipeline execution provenance.
-        * `job_id`: An optional string specifying a specific job ID to run.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
+        provenance : List[CommitProvenance protobuf], optional
+            A list representing the pipeline execution provenance.
+        job_id : str, optional
+            A specific job ID to run.
         """
         return self._req(
             Service.PPS,
@@ -651,15 +721,14 @@ class PPSMixin:
         )
 
     def run_cron(self, pipeline_name):
-        """
-        Explicitly triggers a pipeline with one or more cron inputs to run
+        """Explicitly triggers a pipeline with one or more cron inputs to run
         now.
 
-        Params:
-
-        * `pipeline_name`: A string representing the pipeline name.
+        Parameters
+        ----------
+        pipeline_name : str
+            The pipeline name.
         """
-
         return self._req(
             Service.PPS,
             "RunCron",
@@ -667,21 +736,20 @@ class PPSMixin:
         )
 
     def create_secret(self, secret_name, data, labels=None, annotations=None):
+        """Creates a new secret.
+
+        Parameters
+        ----------
+        secret_name : str
+            The name of the secret to create.
+        data : Dict[str, Union[str, bytes]]
+            The data to store in the secret. Each key must consist of
+            alphanumeric characters ``-``, ``_`` or ``.``.
+        labels : Dict[str, str], optional
+            Kubernetes labels to attach to the secret.
+        annotations : Dict[str, str], optional
+            Kubernetes annotations to attach to the secret.
         """
-        Creates a new secret.
-
-        Params:
-
-        * `secret_name`: The name of the secret to create.
-        * `data`: A dict of string keys -> string or bytestring values to
-        store in the secret. Each key must consist of alphanumeric characters,
-        `-`, `_` or `.`.
-        * `labels`: A dict of string keys -> string values representing the
-        kubernetes labels to attach to the secret.
-        * `annotations`: A dict representing the kubernetes annotations to
-        attach to the secret.
-        """
-
         encoded_data = {}
         for k, v in data.items():
             if isinstance(v, str):
@@ -704,21 +772,18 @@ class PPSMixin:
         return self._req(Service.PPS, "CreateSecret", file=f)
 
     def delete_secret(self, secret_name):
-        """
-        Deletes a new secret.
+        """Deletes a secret.
 
-        Params:
-
-        * `secret_name`: The name of the secret to delete.
+        Parameters
+        ----------
+        secret_name : str
+            The name of the secret to delete.
         """
         secret = pps_proto.Secret(name=secret_name)
         return self._req(Service.PPS, "DeleteSecret", secret=secret)
 
     def list_secret(self):
-        """
-        Lists secrets. Returns a list of `SecretInfo` objects.
-        """
-
+        """Lists secrets. Returns a list of ``SecretInfo`` objects."""
         return self._req(
             Service.PPS,
             "ListSecret",
@@ -726,20 +791,18 @@ class PPSMixin:
         ).secret_info
 
     def inspect_secret(self, secret_name):
-        """
-        Inspects a secret.
+        """Inspects a secret.
 
-        Params:
-
-        * `secret_name`: The name of the secret to inspect.
+        Parameters
+        ----------
+        secret_name : str
+            The name of the secret to inspect.
         """
         secret = pps_proto.Secret(name=secret_name)
         return self._req(Service.PPS, "InspectSecret", secret=secret)
 
     def delete_all(self):
-        """
-        Deletes everything in pachyderm.
-        """
+        """Deletes everything in Pachyderm."""
         return self._req(
             Service.PPS,
             "DeleteAll",
@@ -757,29 +820,33 @@ class PPSMixin:
         use_loki_backend=None,
         since=None,
     ):
-        """
-        Gets logs for a pipeline. Yields `LogMessage` objects.
+        """Gets logs for a pipeline. Yields ``LogMessage`` objects.
 
-        Params:
-
-        * `pipeline_name`: A string representing a pipeline to get
-          logs of.
-        * `data_filters`: An optional iterable of strings specifying the names
-          of input files from which we want processing logs. This may contain
-          multiple files, to query pipelines that contain multiple inputs. Each
-          filter may be an absolute path of a file within a pps repo, or it may
-          be a hash for that file (to search for files at specific versions.)
-        * `master`: An optional bool.
-        * `datum`: An optional `Datum` object.
-        * `follow`: An optional bool specifying whether logs should continue to
-          stream forever.
-        * `tail`: An optional int. If nonzero, the number of lines from the end
-          of the logs to return.  Note: tail applies per container, so you will
-          get tail * <number of pods> total lines back.
-        * `use_loki_backend`: Whether to use loki as a backend for fetching
-          logs. Requires a loki-enabled cluster.
-        * `since`: An optional `Duration` object specifying the start time for
-          returned logs
+        Parameters
+        ----------
+        pipeline_name : str
+            The name of the pipeline.
+        data_filters : List[str], optional
+            A list of the names of input files from which we want processing
+            logs. This may contain multiple files, in case `pipeline_name`
+            contains multiple inputs. Each filter may be an absolute path of a
+            file within a repo, or it may be a hash for that file (to search
+            for files at specific versions).
+        master : bool, optional
+            If true, includes logs from the master
+        datum : Datum protobuf, optional
+            Filters log lines for the specified datum.
+        follow : bool, optional
+            If true, continue to follow new logs as they appear.
+        tail : int, optional
+            If nonzero, the number of lines from the end of the logs to return.
+            Note: tail applies per container, so you will get
+            `tail` * <number of pods> total lines back.
+        use_loki_backend : bool, optional
+            If true, use loki as a backend, rather than Kubernetes, for
+            fetching logs. Requires a loki-enabled cluster.
+        since : Duration protobuf, optional
+            Specifies how far in the past to return logs from.
         """
         return self._req(
             Service.PPS,
@@ -804,27 +871,31 @@ class PPSMixin:
         use_loki_backend=None,
         since=None,
     ):
-        """
-        Gets logs for a job. Yields `LogMessage` objects.
+        """Gets logs for a job. Yields `LogMessage` objects.
 
-        Params:
-
-        * `job_id`: A string representing a job to get logs of.
-        * `data_filters`: An optional iterable of strings specifying the names
-          of input files from which we want processing logs. This may contain
-          multiple files, to query pipelines that contain multiple inputs. Each
-          filter may be an absolute path of a file within a pps repo, or it may
-          be a hash for that file (to search for files at specific versions.)
-        * `datum`: An optional `Datum` object.
-        * `follow`: An optional bool specifying whether logs should continue to
-          stream forever.
-        * `tail`: An optional int. If nonzero, the number of lines from the end
-          of the logs to return.  Note: tail applies per container, so you will
-          get tail * <number of pods> total lines back.
-        * `use_loki_backend`: Whether to use loki as a backend for fetching
-          logs. Requires a loki-enabled cluster.
-        * `since`: An optional `Duration` object specifying the start time for
-          returned logs
+        Parameters
+        ----------
+        job_id : str
+            The ID of the job.
+        data_filters : List[str], optional
+            A list of the names of input files from which we want processing
+            logs. This may contain multiple files, in case `pipeline_name`
+            contains multiple inputs. Each filter may be an absolute path of a
+            file within a repo, or it may be a hash for that file (to search
+            for files at specific versions).
+        datum : Datum protobuf, optional
+            Filters log lines for the specified datum.
+        follow : bool, optional
+            If true, continue to follow new logs as they appear.
+        tail : int, optional
+            If nonzero, the number of lines from the end of the logs to return.
+            Note: tail applies per container, so you will get
+            `tail` * <number of pods> total lines back.
+        use_loki_backend : bool, optional
+            If true, use loki as a backend, rather than Kubernetes, for
+            fetching logs. Requires a loki-enabled cluster.
+        since : Duration protobuf, optional
+            Specifies how far in the past to return logs from.
         """
         return self._req(
             Service.PPS,
@@ -839,14 +910,14 @@ class PPSMixin:
         )
 
     def garbage_collect(self, memory_bytes=None):
-        """
-        Runs garbage collection.
+        """Runs garbage collection.
 
-        Params:
-
-        * `memory_bytes`: An optional int specifying how much memory to use in
-        computing which objects are alive. A larger number will result in more
-        precise garbage collection (at the cost of more memory usage).
+        Parameters
+        ----------
+        memory_bytes : int, optional
+            How much memory to use in computing which objects are alive. A
+            larger number will result in more precise garbage collection (at
+            the cost of more memory usage).
         """
         return self._req(Service.PPS, "GarbageCollect", memory_bytes=memory_bytes)
 
