@@ -40,20 +40,23 @@ test -f requirements.txt && pip wheel -r requirements.txt -w /pfs/out
 
 
 def put_files(client, source_path, commit, dest_path, **kwargs):
+    """Utility function for inserting files from the local `source_path`
+    to Pachyderm. Roughly equivalent to ``pachctl put file [-r]``.
+
+    Parameters
+    ----------
+    client : Client
+        The :class:`.Client` instance to use.
+    source_path : str
+        The file/directory to recursively insert content from.
+    commit : Union[tuple, str, Commit protobuf]
+        The ``Commit`` object to use for inserting files.
+    dest_path : str
+        The destination path in PFS.
+    **kwargs : dict
+        Keyword arguments to forward. See
+        ``PutFileClient.put_file_from_fileobj()`` for details.
     """
-    Utility function for inserting files from the local `source_path`
-    to pachyderm. Roughly equivalent to `pachctl put file [-r]`.
-
-    Params:
-
-    * `client`: The `Client` instance to use.
-    * `source_path`: The file/directory to recursively insert content from.
-    * `commit`: The `Commit` object to use for inserting files.
-    * `dest_path`: The destination path in PFS.
-    * `kwargs`: Keyword arguments to forward. See
-    `PutFileClient.put_file_from_fileobj` for details.
-    """
-
     with client.put_file_client() as pfc:
         if os.path.isfile(source_path):
             pfc.put_file_from_filepath(commit, dest_path, source_path, **kwargs)
@@ -84,9 +87,8 @@ def create_python_pipeline(
     update=False,
     **pipeline_kwargs
 ):
-    """
-    Utility function for creating (or updating) a pipeline specially built for
-    executing python code that is stored locally at `path`.
+    """Utility function for creating (or updating) a pipeline specially built
+    for executing python code that is stored locally at `path`.
 
     A normal pipeline creation process requires you to first build and push a
     container image with the source and dependencies baked in. As an alternative
@@ -95,34 +97,42 @@ def create_python_pipeline(
 
     If `path` references a directory, it should have:
 
-    * A `main.py`, as the pipeline entry-point.
-    * An optional `requirements.txt` that specifies pip requirements.
+    - A ``main.py``, as the pipeline entry-point.
+    - An optional ``requirements.txt`` that specifies pip requirements.
 
-    Params:
-
-    * `client`: The `Client` instance to use.
-    * `path`: The directory containing the python pipeline source, or an
-    individual python file.
-    * `input`: An optional `Input` object specifying the pipeline input.
-    * `pipeline_name`: An optional string specifying the pipeline name.
-    Defaults to using the last directory name in `path`.
-    * `image_pull_secrets`: An optional list of strings specifying the
-    pipeline transform's image pull secrets, which are used for pulling images
-    from a private registry. Defaults to `None`, in which case the public
-    docker registry will be used. See the pipeline spec document for more
-    details.
-    * `debug`: An optional bool specifying whether debug logging should be
-    enabled for the pipeline. Defaults to `False`.
-    * `env`: An optional mapping of string keys to string values specifying
-    custom environment variables.
-    * `secrets`: An optional list of `Secret` objects for secret environment
-    variables.
-    * `image`: An optional string specifying the docker image to use for the
-    pipeline. Defaults to using pachyderm's official python language builder.
-    * `update`: Whether to act as an upsert.
-    * `pipeline_kwargs`: Keyword arguments to forward to `create_pipeline`.
+    Parameters
+    ----------
+    client : Client
+        The `Client` instance to use.
+    path : str
+        The directory containing the python pipeline source, or an individual
+        python file.
+    input : Input protobuf, optional
+        An ``Input`` object specifying the pipeline input.
+    pipeline_name : str, optional
+        A string specifying the pipeline name. Defaults to using the last
+        directory name in `path`.
+    image_pull_secrets : List[str], optional
+        A list of strings specifying the pipeline transform's image pull
+        secrets, which are used for pulling images from a private registry.
+        Defaults to `None`, in which case the public docker registry will be
+        used. See the pipeline spec document for more details.
+    debug : bool, optional
+        Specifies whether debug logging should be enabled for the pipeline.
+        Defaults to `False`.
+    env : Dict[str, str], optional
+        A mapping of string keys to string values specifying custom environment
+        variables.
+    secrets : List[Secret protobufs], optional
+        A list of `Secret` objects for secret environment variables.
+    image : str, optional
+        A string specifying the docker image to use for the pipeline. Defaults
+        to using pachyderm's official python language builder.
+    update : bool, optional
+        Whether to act as an upsert.
+    **pipeline_kwargs : dict
+        Keyword arguments to forward to `create_pipeline`.
     """
-
     return client.create_pipeline(
         pipeline_name or Path(path).name,
         Transform(
@@ -141,14 +151,12 @@ def create_python_pipeline(
 
 
 def parse_json_pipeline_spec(j):
-    """
-    Parses a string of JSON into a `CreatePipelineRequest` protobuf.
-    """
+    """Parses a string of JSON into a `CreatePipelineRequest` protobuf."""
     return json_format.Parse(j, CreatePipelineRequest())
 
 
 def parse_dict_pipeline_spec(d):
-    """
-    Parses a dict of serialized JSON into a `CreatePipelineRequest` protobuf.
+    """Parses a dict of serialized JSON into a `CreatePipelineRequest`
+    protobuf.
     """
     return json_format.ParseDict(d, CreatePipelineRequest())
